@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::VerifyPhases; # git description: v0.013-6-g5690f92
+package Dist::Zilla::Plugin::VerifyPhases; # git description: v0.014-6-ge0c81aa
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Compare data and files at different phases of the distribution build process
 # KEYWORDS: plugin distribution configuration phase verification validation
-# vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.014';
+our $VERSION = '0.015';
 
 use Moose;
 with
@@ -105,7 +105,7 @@ sub gather_files
     my $zilla = $self->zilla;
     my $meta = find_meta($zilla);
 
-    foreach my $attr_name (qw(name version release_status abstract main_module authors distmeta _share_dir_map))
+    foreach my $attr_name (qw(name version release_status abstract main_module authors distmeta))
     {
         next if exists $zilla_constructor_args{$attr_name};
         my $attr = $meta->find_attribute_by_name($attr_name);
@@ -133,9 +133,9 @@ sub gather_files
 }
 
 # since last phase,
-# new files added: no
-# files removed: no
-# files renamed: no
+# new files added: not ok
+# files removed: not ok
+# files renamed: not ok
 # encoding changed: ok to now; no from now on
 # contents: ignore
 sub set_file_encodings
@@ -154,10 +154,10 @@ sub set_file_encodings
 }
 
 # since last phase,
-# new files added: no
-# files removed: ok to now; no from now on
-# files renamed: no
-# encoding changed: no
+# new files added: not ok
+# files removed: ok to now; not ok from now on
+# files renamed: not ok
+# encoding changed: not ok
 # contents: ignore
 sub prune_files
 {
@@ -199,12 +199,12 @@ sub prune_files
 my $distmeta;
 
 # since last phase,
-# new files added: no
-# files removed: no
+# new files added: not ok
+# files removed: not ok
 # files renamed: allowed
-# encoding changed: no
-# record contents: ok to now; no from now on
-# distmeta changed: ok to now; no from now on
+# encoding changed: not ok
+# record contents: ok to now; not ok from now on
+# distmeta changed: ok to now; not ok from now on
 # no prerequisites have been added yet
 sub munge_files
 {
@@ -270,10 +270,10 @@ sub munge_files
 }
 
 # since last phase,
-# new files added: no
-# files removed: no
-# files renamed: no
-# change contents: no
+# new files added: not ok
+# files removed: not ok
+# files renamed: not ok
+# change contents: not ok
 # distmeta has not changed
 sub after_build
 {
@@ -353,11 +353,11 @@ Dist::Zilla::Plugin::VerifyPhases - Compare data and files at different phases o
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 SYNOPSIS
 
-In your F<dist.ini>:
+At the end of your F<dist.ini>:
 
     [VerifyPhases]
 
@@ -406,10 +406,6 @@ authors
 
 metadata
 
-=item *
-
-_share_dir_map
-
 =back
 
 Running at the end of the C<-EncodingProvider> phase, it forces all encodings
